| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Connect.ListAgentStatuses
Description
This API is in preview release for Amazon Connect and is subject to change.
Lists agent statuses.
This operation returns paginated results.
Synopsis
- data ListAgentStatuses = ListAgentStatuses' {}
- newListAgentStatuses :: Text -> ListAgentStatuses
- listAgentStatuses_agentStatusTypes :: Lens' ListAgentStatuses (Maybe [AgentStatusType])
- listAgentStatuses_maxResults :: Lens' ListAgentStatuses (Maybe Natural)
- listAgentStatuses_nextToken :: Lens' ListAgentStatuses (Maybe Text)
- listAgentStatuses_instanceId :: Lens' ListAgentStatuses Text
- data ListAgentStatusesResponse = ListAgentStatusesResponse' {}
- newListAgentStatusesResponse :: Int -> ListAgentStatusesResponse
- listAgentStatusesResponse_agentStatusSummaryList :: Lens' ListAgentStatusesResponse (Maybe [AgentStatusSummary])
- listAgentStatusesResponse_nextToken :: Lens' ListAgentStatusesResponse (Maybe Text)
- listAgentStatusesResponse_httpStatus :: Lens' ListAgentStatusesResponse Int
Creating a Request
data ListAgentStatuses Source #
See: newListAgentStatuses smart constructor.
Constructors
| ListAgentStatuses' | |
Fields
| |
Instances
Arguments
| :: Text | |
| -> ListAgentStatuses |
Create a value of ListAgentStatuses with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:agentStatusTypes:ListAgentStatuses', listAgentStatuses_agentStatusTypes - Available agent status types.
$sel:maxResults:ListAgentStatuses', listAgentStatuses_maxResults - The maximum number of results to return per page.
ListAgentStatuses, listAgentStatuses_nextToken - The token for the next set of results. Use the value returned in the
previous response in the next request to retrieve the next set of
results.
ListAgentStatuses, listAgentStatuses_instanceId - The identifier of the Amazon Connect instance. You can find the
instanceId in the ARN of the instance.
Request Lenses
listAgentStatuses_agentStatusTypes :: Lens' ListAgentStatuses (Maybe [AgentStatusType]) Source #
Available agent status types.
listAgentStatuses_maxResults :: Lens' ListAgentStatuses (Maybe Natural) Source #
The maximum number of results to return per page.
listAgentStatuses_nextToken :: Lens' ListAgentStatuses (Maybe Text) Source #
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
listAgentStatuses_instanceId :: Lens' ListAgentStatuses Text Source #
The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
Destructuring the Response
data ListAgentStatusesResponse Source #
See: newListAgentStatusesResponse smart constructor.
Constructors
| ListAgentStatusesResponse' | |
Fields
| |
Instances
newListAgentStatusesResponse Source #
Create a value of ListAgentStatusesResponse with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:agentStatusSummaryList:ListAgentStatusesResponse', listAgentStatusesResponse_agentStatusSummaryList - A summary of agent statuses.
ListAgentStatuses, listAgentStatusesResponse_nextToken - If there are additional results, this is the token for the next set of
results.
$sel:httpStatus:ListAgentStatusesResponse', listAgentStatusesResponse_httpStatus - The response's http status code.
Response Lenses
listAgentStatusesResponse_agentStatusSummaryList :: Lens' ListAgentStatusesResponse (Maybe [AgentStatusSummary]) Source #
A summary of agent statuses.
listAgentStatusesResponse_nextToken :: Lens' ListAgentStatusesResponse (Maybe Text) Source #
If there are additional results, this is the token for the next set of results.
listAgentStatusesResponse_httpStatus :: Lens' ListAgentStatusesResponse Int Source #
The response's http status code.