| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Connect.Types.ContactFilter
Description
Synopsis
Documentation
data ContactFilter Source #
Filters user data based on the contact information that is associated to the users. It contains a list of contact states.
See: newContactFilter smart constructor.
Constructors
| ContactFilter' | |
Fields
| |
Instances
newContactFilter :: ContactFilter Source #
Create a value of ContactFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:contactStates:ContactFilter', contactFilter_contactStates - A list of up to 9
contact states.
contactFilter_contactStates :: Lens' ContactFilter (Maybe [ContactState]) Source #
A list of up to 9 contact states.