| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Connect.Types.ControlPlaneTagFilter
Description
Synopsis
- data ControlPlaneTagFilter = ControlPlaneTagFilter' {}
- newControlPlaneTagFilter :: ControlPlaneTagFilter
- controlPlaneTagFilter_andConditions :: Lens' ControlPlaneTagFilter (Maybe [TagCondition])
- controlPlaneTagFilter_orConditions :: Lens' ControlPlaneTagFilter (Maybe [[TagCondition]])
- controlPlaneTagFilter_tagCondition :: Lens' ControlPlaneTagFilter (Maybe TagCondition)
Documentation
data ControlPlaneTagFilter Source #
An object that can be used to specify Tag conditions inside the
SearchFilter. This accepts an OR of AND (List of List) input
where:
- Top level list specifies conditions that need to be applied with
ORoperator - Inner list specifies conditions that need to be applied with
ANDoperator.
See: newControlPlaneTagFilter smart constructor.
Constructors
| ControlPlaneTagFilter' | |
Fields
| |
Instances
newControlPlaneTagFilter :: ControlPlaneTagFilter Source #
Create a value of ControlPlaneTagFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:andConditions:ControlPlaneTagFilter', controlPlaneTagFilter_andConditions - A list of conditions which would be applied together with an AND
condition.
$sel:orConditions:ControlPlaneTagFilter', controlPlaneTagFilter_orConditions - A list of conditions which would be applied together with an OR
condition.
$sel:tagCondition:ControlPlaneTagFilter', controlPlaneTagFilter_tagCondition - A leaf node condition which can be used to specify a tag condition.
controlPlaneTagFilter_andConditions :: Lens' ControlPlaneTagFilter (Maybe [TagCondition]) Source #
A list of conditions which would be applied together with an AND
condition.
controlPlaneTagFilter_orConditions :: Lens' ControlPlaneTagFilter (Maybe [[TagCondition]]) Source #
A list of conditions which would be applied together with an OR
condition.
controlPlaneTagFilter_tagCondition :: Lens' ControlPlaneTagFilter (Maybe TagCondition) Source #
A leaf node condition which can be used to specify a tag condition.