| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Connect.Types.TagCondition
Description
Synopsis
Documentation
data TagCondition Source #
A leaf node condition which can be used to specify a tag condition, for
example, HAVE BPO = 123.
See: newTagCondition smart constructor.
Constructors
| TagCondition' | |
Instances
newTagCondition :: TagCondition Source #
Create a value of TagCondition with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:tagKey:TagCondition', tagCondition_tagKey - The tag key in the tag condition.
$sel:tagValue:TagCondition', tagCondition_tagValue - The tag value in the tag condition.
tagCondition_tagKey :: Lens' TagCondition (Maybe Text) Source #
The tag key in the tag condition.
tagCondition_tagValue :: Lens' TagCondition (Maybe Text) Source #
The tag value in the tag condition.